import numpy as np
from modshogun import RealFeatures
from modshogun import MulticlassLabels
from modshogun import CSVFile
from modshogun import MulticlassAccuracy
from modshogun import SerializableAsciiFile
from modshogun import QDA
from modshogun import WrappedObjectArray

f_feats_train = CSVFile("../../data/classifier_4class_2d_linear_features_train.dat")
f_feats_test = CSVFile("../../data/classifier_4class_2d_linear_features_test.dat")
f_labels_train = CSVFile("../../data/classifier_4class_2d_linear_labels_train.dat")
f_labels_test = CSVFile("../../data/classifier_4class_2d_linear_labels_test.dat")

#![create_features]
features_train = RealFeatures(f_feats_train)
features_test = RealFeatures(f_feats_test)
labels_train = MulticlassLabels(f_labels_train)
labels_test = MulticlassLabels(f_labels_test)
#![create_features]

#![create_instance]
qda = QDA(features_train, labels_train, 0.0001, True)
#![create_instance]

#![train_and_apply]
qda.train()
labels_predict = qda.apply_multiclass(features_test)
#![train_and_apply]

#![extract_mean_and_cov]
classlabel = 1
m = qda.get_mean(classlabel)
c = qda.get_cov(classlabel)
#![extract_mean_and_cov]

#![evaluate_accuracy]
eval = MulticlassAccuracy()
accuracy = eval.evaluate(labels_predict, labels_test)
#![evaluate_accuracy]

# additional integration testing variables
output = labels_predict.get_labels()

# Serialize output for integration testing (automatically generated)
__sg_storage = WrappedObjectArray()
__sg_storage_file = SerializableAsciiFile("quadratic_discriminant_analysis.dat", 'w')
__sg_storage.append_wrapped_int(classlabel, "classlabel")
__sg_storage.append_wrapped_real_vector(m, "m")
__sg_storage.append_wrapped_real_matrix(c, "c")
__sg_storage.append_wrapped_real(accuracy, "accuracy")
__sg_storage.append_wrapped_real_vector(output, "output")
__sg_storage.save_serializable(__sg_storage_file)
